__title__ = 'Django-notifications-views'
__description__ = 'Django-notifications-views is an extension for Django-notifications-hq that provides a viewset for the notifications.'
__url__ = 'https://github.com/nachoborrelli/Django-notifications-views'
__version__ = '0.1.5'
__author__ = '@nachoborrelli https://github.com/nachoborrelli'
__author_email__ = 'nacho2911@hotmail.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2024 @nachoborrelli https://github.com/nachoborrelli'
